@@ -25,7 +25,7 @@ use Carp;
 use vars qw($AUTOLOAD $VERSION @ISA);
 @ISA = qw(Exporter);
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 ###############################################################################
 #
@@ -676,8 +676,12 @@ sub set_merge {
 #
 sub set_bold {
 
-    my $self          = shift;
-       $self->{_bold} = $_[0] ? 1 : 0;
+    my $self = shift;
+    my $bold = shift;
+
+    $bold = 1 if not defined $bold;
+
+    $self->{_bold} = $bold ? 1 : 0;
 }
 
 
@@ -884,6 +888,6 @@ Software programs that read or write files that comply with the Microsoft specif
 
 =head1 COPYRIGHT
 
- MM-MMX, John McNamara.
+ MM-MMXI, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
